camelot.camelot.view.filters

Package camelot :: Package camelot :: Package view :: Module filters |
[hide private]
[frames] | no frames]

# Module filters

source code

Python structures to represent filters. These structures can be transformed to QT forms.

Classes | [hide private]
| Filter Base class for filters
| GroupBoxFilter Filter where the items are displayed in a QGroupBox
| ComboBoxFilter Filter where the items are displayed in a QComboBox

Functions | [hide private]
structure_to_filter(structure) Convert a python data structure to a filter, using the following rules : | source code

Function Details | [hide private]

### structure_to_filter(structure) | source code
Convert a python data structure to a filter, using the following rules : if structure is an instance of Filter, return structure else create a GroupBoxFilter from the structure